@@ -1,3 +1,4 @@
+import sys
 import time
 import argparse
 import requests
@@ -7,6 +8,7 @@ parser = argparse.ArgumentParser(description="Process some integers.")
 parser.add_argument("api_key", help="PlanScore.org API key")
 parser.add_argument("input_source", help="Path for input GeoJSON file")
 parser.add_argument("output_index", help="Path for output index JSON file")
+parser.add_argument("--endpoint-url", help="Endpoint URL", default="api.planscore.org")
 
 
 def main():
@@ -14,13 +16,20 @@ def main():
 
     with open(args.input_source, "rb") as file1:
         posted = requests.post(
-            "https://api.planscore.org/api-upload",
+            f"https://{args.endpoint_url}/api-upload",
             data=file1,
             headers={
                 "Authorization": f"Bearer {args.api_key}",
             },
         )
 
+        if posted.status_code != 200:
+            print(posted.json(), file=sys.stderr)
+            raise RuntimeError(
+                f"Bad status response from {args.endpoint_url}: {posted.status_code}"
+            )
+            exit(1)
+
         index_url = posted.json()["index_url"]
         plan_url = posted.json()["plan_url"]
 
